# Retro gaming distributions

- [RetroPie vs Recalbox vs Lakka vs Batocera for retro gaming on the Raspberry Pi](https://www.electromaker.io/blog/article/retropie-vs-recalbox-vs-lakka-for-retro-gaming-on-the-raspberry-pi)

## Building blocks

- [libretro/RetroArch](https://www.retroarch.com/)
  - [GitHub](https://github.com/libretro/RetroArch)
    - Last [release](https://github.com/libretro/RetroArch/releases) 2025-01
- [EmulationStation](https://emulationstation.org/) (stale)
  - [GitHub](https://github.com/Aloshi/EmulationStation/tree/master#building)
    - Last [release](https://github.com/Aloshi/EmulationStation/releases): 2014 (!)

## Lakka

- [Website](https://www.lakka.tv/)
- [GitHub](https://github.com/libretro/Lakka-LibreELEC)
- Based on [LibreELEC](https://libreelec.tv/) and RetroArch
- [Libretro](https://www.libretro.com/)'s reference operating system distribution
- Up to date, 46k commits, 1.8k stars
- Last release 2024-04

### Lakka config

- Change GUI language (`Settings/User`)
- Connect to Wifi
- SSH (`Settings/Services`)
  - User: `root`, PW: `root`
- Audio
  - Enable audio via HDMI
  - Add `hdmi_drive=2` to `/flash/config.txt`
- Bluetoth
  - [8Bitdo Wireless Controller](https://www.lakka.tv/doc/8Bitdo-Wireless-Controller/)
  - won't pair automatically via GUI, manual config needed
  - Couldn't get persistent bluetooth config working

```sh
mount -o remount,rw /flash
vi /flash/config.txt
```

- Grow `/storage` filesystem

## Recalbox

- [Website](https://www.recalbox.com/)
- Based on EmulationStation and RetroArch
- [Gitlab](https://gitlab.com/recalbox/recalbox)
- Up to date, 44k commits
- [Last release](https://gitlab.com/recalbox/recalbox/-/releases) 2024-11
- Not based on any distribution, but build from scratch with [buildroot](https://buildroot.org/)

## Batocera

- [Website](https://batocera.org/)
  - Based on EmulationStation and RetroArch
- [Github](https://github.com/batocera-linux/batocera.linux)
  - Very active, 79k commits, 2.3k stars
- [Docs/wiki](https://wiki.batocera.org/)
  - [Add games/BIOS files to Batocera](https://wiki.batocera.org/add_games_bios)
- Not based on any distribution, but build from scratch with [buildroot](https://buildroot.org/)
- Better out-of-the-box user experience than RetroPie
- Uses Sway/Wayland !
-

Sync roms:

```sh
rsync -av /home/varac/Software/batocera/roms/ batocera:/media/SHARE/roms
```

### Updates

- [Upgrading/downgrading Batocera](https://wiki.batocera.org/upgrade_manually#upgrading_downgrading_batocera)

Upgrading successfully only works in GUI mode, not in manual mode !

Manual upgrade:

```sh
batocera-upgrade https://batocera.org/upgrades/x86_64/stable/last
```

- Manual update issue:
  - `need to download 3308mb; Not enough space on /boot to download the update`
  - `/boot` is only 4 GB big, while /userdata (partition 2) is 55 GB big

### Controller

- [Hotkey shortcuts](https://wiki.batocera.org/basic_commands)
- [Map a controller](https://wiki.batocera.org/configure_a_controller)

#### Keyboard

[Keyboard shortcuts](https://defkey.com/batocera-shortcuts)

#### Bluetooth pairing

- [bluetooth controllers - manual setup](https://wiki.batocera.org/bluetooth_controllers_-_manual_setup)
- No persitent bluetooth pairing with controllers, often need to repair,
  no always working

### HDMI Audio

- Settings / Sound / HDMI

### Terminal

Switch to TTY with `ctrl+alt+f3` and back with `ctrl+alt+f1`

### Keyboard layout

[Switching the Keyboard layout is not working](https://github.com/batocera-linux/batocera.linux/issues/7382#issuecomment-1301912470)

Edit `~/userdata/systemsettings/batocera.conf` and set:

```sh
system.kblayout
system.kbvariant
```

(Note: Using `de`/`nodeadkeys` doesn't fix the layout...)

## Retropie

- [Retropie docs](https://retropie.org.uk/docs)
- Builds upon Raspbian, [EmulationStation](https://emulationstation.org/), [RetroArch](https://www.retroarch.com/)

Logs:

- `./configs/all/emulationstation/es_log.txt`

Config: `/opt/retropie/configs/all/retroarch.cfg`

Sync roms:

```sh
rsync -av /home/varac/Software/RetroPie/roms/ retropie:RetroPie/roms
```

## ROMs

- [Where to Download Retropie ROMs?](https://raspberrytips.com/download-retropie-roms/)
