# F5 VPN

- [Website](https://www.f5.com)
- [Technical support forum](https://community.f5.com/t5/technical-forum/bd-p/TechnicalForum)
  - [Troubleshooting | BIG-IP Edge Client operations guide](https://my.f5.com/manage/s/article/K32311645#link_04_05)

## Clients

- [CLI-Only Alternatives](https://github.com/zrhoffman/f5vpn-arch#cli-only-alternatives)
  - [svpn-login](https://github.com/zrhoffman/svpn-login): Last commit 2021-03
  - [f5vpn-login](https://github.com/zrhoffman/f5vpn-login): Last commit 2020
- [NetworkManager-f5vpn](https://github.com/ohwgiles/NetworkManager-f5vpn)
  "Now that OpenConnect added support for F5 SSL VPN, this project is obsolete"
- [F5 SSL VPN on unsupported Linux distribution (Arch Linux, Manjaro, maybe others)](https://community.f5.com/t5/technical-forum/f5-ssl-vpn-on-unsupported-linux-distribution-arch-linux-manjaro/td-p/189988)
- [CLI-Only Alternatives](https://github.com/zrhoffman/f5vpn-arch#cli-only-alternatives)
  - [svpn-login](https://github.com/zrhoffman/svpn-login): Last commit 2021-03
  - [f5vpn-login](https://github.com/zrhoffman/f5vpn-login): Last commit 2020
- [NetworkManager-f5vpn](https://github.com/ohwgiles/NetworkManager-f5vpn)
  "Now that OpenConnect added support for F5 SSL VPN, this project is obsolete"

### go-f5

- [GitHub](https://github.com/kayrus/gof5)
- Last release 2021
- [PR: Parse f5vpn urls](https://github.com/kayrus/gof5/pull/44)
- Config at `~/.gof5/config.yaml`

#### Setup

To make it work with f5-URLs from the browser.
Still WIP, not working so far, see [this comment](https://github.com/kayrus/gof5/pull/44#issuecomment-2616021879)

Compile go-f5 from this MR: [Parse f5vpn urls #44](https://github.com/kayrus/gof5/pull/44)

```sh
git clone https://github.com/fwiesel/gof5
cd gof5
git checkout f5vpn_handler
make build
ln -s $(pwd)/bin/gof5_linux_amd64 ~/bin/download/gof5_linux_amd64
```

Set capabilities to not run the binary as root:

```sh
sudo setcap cap_net_admin,cap_net_bind_service+ep bin/gof5_linux_amd64
```

Allow modification to `systemd-resolved`:

```sh
sudo mkdir -p /etc/polkit-1/localauthority/50-local.d/
sudo cp org.freedesktop.resolve1.pkla /etc/polkit-1/localauthority/50-local.d/
sudo systemctl restart polkit.service
```

Create desktop entry in `~/.local/share/applications/gof5.desktop`:

```ini
[Desktop Entry]
Name=gof5
Exec=/home/varac/bin/download/gof5_linux_amd64 %u
Type=Application
MimeType=x-scheme-handler/f5-vpn;
NoDisplay=true
```

Add mimetype default:

```sh
$ xdg-mime default gof5.desktop x-scheme-handler/f5-vpn
$ xdg-mime query default x-scheme-handler/f5-vpn
gof5.desktop
```

### openconnect

- [Openconnect](https://www.infradead.org/openconnect/)
- [GlobalProtect-openconnect](https://github.com/yuezk/GlobalProtect-openconnect)
  A GlobalProtect VPN client (GUI) for Linux, based on OpenConnect and built with Qt5, supports SAML auth mode.
- [Docs](https://www.infradead.org/openconnect/f5.html)
- [Gitlab issues](https://gitlab.com/openconnect/openconnect/-/issues/?search=f5&sort=created_asc&state=opened&first_page_size=20)
- Doesn't work: [Support f5-vpn:// URIs](https://gitlab.com/openconnect/openconnect/-/issues/639)
- I couldn't get it to work with openconnect

Start:

```sh
openconnect --protocol=f5 --dump -vvv $SERVER
```

### Official F5 client

- Native installation packages only in `rpm` and `deb` format
- [Docs](https://techdocs.f5.com/kb/en-us/products/big-ip_apm/manuals/product/apm-client-configuration-11-4-0/4.html)
  - [F5 SSL VPN on unsupported Linux distribution (Arch Linux, Manjaro, maybe others)](https://community.f5.com/t5/technical-forum/f5-ssl-vpn-on-unsupported-linux-distribution-arch-linux-manjaro/td-p/189988)
- Config at `~/.F5Networks/f5networks.conf`
- Log at `~/.F5Networks/vpn.log`
  Also contains some F5 tunnel config details

Debug with `export QT_DEBUG_PLUGINS=1`

#### Arch/AUR packages

- [AUR package: f5vpn](https://aur.archlinux.org/packages/f5vpn)
  - (GUI) VPN client using the Point-to-Point Protocol to connect to F5Networks BIG-IP APM
- [AUR package: f5fpc](https://aur.archlinux.org/packages/f5fpc)
  - Command-line VPN client using FastPPP to connect to F5Networks BIG-IP APM 13.0

##### f5vpn

- [f5vpn-arch GitHub](https://github.com/zrhoffman/f5vpn-arch)
- [AUR package](https://aur.archlinux.org/packages/f5vpn)

Steps:

Install package:

```sh
pamac install f5vpn
```

Add mimetype default:

```sh
$ xdg-mime default com.f5.f5vpn.desktop x-scheme-handler/f5-vpn
$ xdg-mime query default x-scheme-handler/f5-vpn
com.f5.f5vpn.desktop
```

Fix wayland issue where client crashes with `qt.qpa.plugin: Could not find the Qt platform plugin "wayland" in ""`:

Add `Exec=/usr/sbin/bash -c "export QT_QPA_PLATFORM=xcb; /opt/f5/vpn/f5vpn %u"`
to `/usr/share/applications/com.f5.f5vpn.desktop`

### Official client on Arch

Download official f5-client Debian package, i.e.

```sh
wget https://huskyonnet-ns.uw.edu/public/download/linux_f5vpn.x86_64.deb -O ~/projects/vpn/f5-client/native/linux_f5vpn.x86_64.deb
```

Extract content:

```sh
cd ~/projects/vpn/f5-client/native/
ar x linux_f5vpn.x86_64.deb
tar -xzf control.tar.gz
tar -xzf data.tar.gz
sudo cp -a opt/f5 /opt/f5
sudo ./postinst
```
