# General

- [Arch wiki: Transport Layer Security](https://wiki.archlinux.org/title/Transport_Layer_Security)
  - [Adding a trusted CA certificate](https://wiki.archlinux.org/title/User:Grawity/Adding_a_trusted_CA_certificate)

## Certificate authorities

- [Arch wiki: Certificate authorities](https://wiki.archlinux.org/title/Transport_Layer_Security#Certificate_authorities)

### System cert store

- `/etc/ssl`
- `/etc/ca-certificates`
- Arch/Manjaro: See `/usr/share/ca-certificates/trust-source/README`

### Network Security Services (NSS)

- Chromium, Firefox, Thunderbird, Evolution, SeaMonkey use NSS for retrieving
  trusted CAs.
  - [Chromium docs: Linux Cert Management](https://chromium.googlesource.com/chromium/src/+/master/docs/linux/cert_management.md)
- [Firefox wiki: Network Security Services (NSS)](https://firefox-source-docs.mozilla.org/security/nss/index.html)

Usage:

List certs:

```sh
certutil -d sql:$HOME/.pki/nssdb/ -L
```

Add cert:

```sh
certutil -d sql:$HOME/.pki/nssdb -A -t TC -n test-cert -i test.cert
```

Add multiple certs:

```sh
for n in *.crt; do certutil -d sql:$HOME/.pki/nssdb -A -t TC -n $n -i $n; done
```

## OpenSSL

- [OpenSSL Command-Line HOWTO](http://www.madboa.com/geek/openssl/)

## Show all certs in cert chain

```sh
openssl crl2pkcs7 -nocrl -certfile lets-encrypt-root.pem \
  | openssl pkcs7 -print_certs -text -noout
openssl crl2pkcs7 -nocrl -certfile lets-encrypt-root.pem \
  | openssl pkcs7 -print_certs -text -noout | grep -A4 Issuer:
```

## CAs

### Add custom CA

i.e. [hackint root CA](https://www.hackint.org/ca):

```sh
sudo wget https://www.hackint.org/crt/rootca.crt -O /usr/local/share/ca-certificates/hackint-rootca.crt
```

Check fp:

```sh
openssl x509 -noout -fingerprint -sha256 -in /usr/local/share/ca-certificates/hackint-rootca.crt
```

Update system CA certs:

```sh
sudo update-ca-certificates
```

Test:

```sh
gnutls-cli irc.hackint.org -p 6697 --print-cert < /dev/null
gnutls-cli irc.hackint.org -p 6697 --print-cert < /dev/null \
  | certtool --verify-chain \
  < /usr/local/share/ca-certificates/hackint-rootca.crt
```

### Search CAs

```sh
awk -v cmd='openssl x509 -noout -subject' ' /BEGIN/{close(cmd)};{print | cmd}' \
  < /etc/ssl/certs/ca-certificates.crt
```

## Inspect cert

```sh
 openssl x509 -text  -in /etc/openvpn/cougar.leap.se/keys/ca.cr
```

## Cert Validation with openssl

Check remote cert:

```sh
echo | openssl s_client -showcerts -connect example.com:443 2>/dev/null | \
  openssl x509 -text
```

Check local cert:

```sh
openssl x509 -in www.example.org.crt -noout -dates
```

Check validity via network connection:

```sh
openssl s_client -connect jabber.org:5222  -starttls xmpp
openssl s_client -servername bitmask.net  -connect bitmask.net:443 -CApath /etc/ssl/certs
openssl s_client -connect mail.bitrigger.de:25 -starttls smtp

openssl s_client  -connect hbci-pintan.gad.de:443 -CApath /etc/ssl/certs \
  < /dev/null | grep Verify
```

Show cert:

```sh
true | openssl s_client -connect k8s-at-home.com:443 -showcerts
echo | openssl s_client -showcerts -servername google.com \
  -connect charts.gabe565.com:443 2>/dev/null | openssl x509 -inform pem -noout -tex
```

## Fingerprints

```sh
openssl x509  -noout -in cert.pem -fingerprint -startdate
```

## TLS smtp with openssl

```sh
openssl s_client -connect mail.riseup.net:25 -starttls smtp \
  -CApath /etc/ssl/certs |grep Verify
```

Imap:

```sh
openssl s_client -connect bitrigger.de:993 -CApath /etc/ssl/certs |grep Verify
```

## Convert p7b to pem/txt format

```sh
openssl pkcs7 -inform der -in IdenTrustCommercialRootCA.p7b -out IdenTrustCommercialRootCA.p7b.txt
openssl pkcs7 -print_certs -in IdenTrustCommercialRootCA.p7b.txt -out IdenTrustCommercialRootCA.pem
```
